GromacsWrapper package — GromacsWrapper 0.5.0-dev documentation

# GromacsWrapper package

The `gromacs` package makes Gromacs tools available via thin python wrappers. In addition, it provides little building blocks to solve commonly encountered tasks.

Contents:

- `gromacs` – GromacsWrapper Package Overview
  - Modules
  - Examples
  - Warnings and Exceptions
  - Logging
  - Version
- Gromacs core modules
  - `gromacs.core` – Core functionality
  - `gromacs.config` – Configuration for GromacsWrapper
  - `gromacs.environment` – Run time modification of behaviour
  - `gromacs.formats` – Accessing various files
  - `gromacs.utilities` – Helper functions and classes
  - `gromacs.tools` – Gromacs commands classes
- Gromacs building blocks
  - `gromacs.cbook` – Gromacs Cook Book
  - `gromacs.setup` – Setting up a Gromacs MD run
  - `gromacs.scaling` – Partial tempering
  - `gromacs.qsub` – utilities for batch submission systems
  - Managing jobs remotely
  - `gromacs.run` – Running simulations